Module uim.codec.parser.decoder
===============================
Decoder classes
===============
This package contains all decoders for the different versions of the Universal Ink Model:

- Version 3.0.0
- Version 3.1.0

Sub-modules
-----------
* uim.codec.parser.decoder.base
* uim.codec.parser.decoder.decoder_3_0_0
* uim.codec.parser.decoder.decoder_3_1_0